sqlobject.tests.test_cyclic_reference module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_cyclic_reference module

class `sqlobject.tests.test_cyclic_reference.` `SOTestCyclicRefA`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `blobcol`
  property `fkeyb`
  property `fkeybID`
  `j` = test_cyclic_ref_a_table
  property `name`
  property `number`
  `q` = test_cyclic_ref_a_table
  property `short`
  property `so_time`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'test_id_here'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_cyclic_reference.SOTestCyclicRefA`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'test_cyclic_ref_a_table'

class `sqlobject.tests.test_cyclic_reference.` `SOTestCyclicRefB`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `blobcol`
  property `fkeya`
  property `fkeyaID`
  `j` = test_cyclic_ref_b_table
  property `name`
  property `number`
  `q` = test_cyclic_ref_b_table
  property `short`
  property `so_time`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'test_id_here'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_cyclic_reference.SOTestCyclicRefB`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'test_cyclic_ref_b_table'

`sqlobject.tests.test_cyclic_reference.` `test_cyclic_reference`()